@@ -1,16 +1,16 @@
-from rest_framework_mongoengine.serializers import DocumentSerializer
-from .models import Monitor
+from rest_framework import serializers
+from .models import AnalysisMonitor
 
 
-class MonitorSerializer(DocumentSerializer):
+class AnalysisMonitorSerializer(serializers.ModelSerializer):
 
     def create(self, validated_data):
         request = self.context['request']
         ip = request.META.get('HTTP_X_FORWARDED_FOR') if request.META.get(
             'HTTP_X_FORWARDED_FOR') else request.META.get('REMOTE_ADDR')
-        validated_data['user']['ip'] = ip
+        validated_data['user_ip'] = ip
         return self.Meta.model.objects.create(**validated_data)
 
     class Meta:
-        model = Monitor
+        model = AnalysisMonitor
         fields = '__all__'
